@@ -22,7 +22,11 @@ class SmartZoneClient(SmartZoneBase):
     def datetemp(self, date_range):
         a = int(date_range[0].timestamp()*1000)
         b = int(date_range[1].timestamp()*1000)
-        date_range = (a + 100, b + 100)
+        if (a > 0):
+            a += 1000
+        if (b > 0):
+            b += 1000
+        date_range = (a, b)
         return date_range
 
 ########## LOGON SESSION
